plugins {
    alias(libs.plugins.android.application)
    alias(libs.plugins.kotlin.android)
    alias(libs.plugins.kotlin.compose)
}

android {
    buildFeatures.buildConfig = true
    dependenciesInfo {
        // Disables dependency metadata when building APKs (for IzzyOnDroid/F-Droid)
        includeInApk = false
        // Disables dependency metadata when building Android App Bundles (for Google Play)
        includeInBundle = true
    }

    namespace = "com.zell_mbc.publicartexplorer"
    compileSdk = 35

    defaultConfig {
        applicationId = "com.zell_mbc.publicartexplorer"
        minSdk = 24
        targetSdk = 36
        versionCode = 28
        versionName = "1.0.8"

        testInstrumentationRunner = "androidx.test.runner.AndroidJUnitRunner"

        // Do not include the X86 binaries to keep the apk size down
        // Enable before compiling a release
       /*ndk {
            abiFilters.addAll(listOf("armeabi-v7a", "arm64-v8a"))
        }*/
    }

    flavorDimensions += "version"
    productFlavors {
        create("foss") {
            dimension = "version"
            applicationIdSuffix = ".foss"
            //resValue("integer", "flavour", "0")
            buildConfigField("String", "FLAVOUR", "\"foss\"")
        }
        create("play") {
            dimension = "version"
            applicationIdSuffix = ".play"
            //resValue("integer", "flavour", "1")
            buildConfigField("String", "FLAVOUR", "\"play\"")
        }
    }

    buildTypes {
        release {
            isMinifyEnabled = false
            proguardFiles(
                getDefaultProguardFile("proguard-android-optimize.txt"),
                "proguard-rules.pro"
            )
        }
    }

    compileOptions {
        sourceCompatibility = JavaVersion.VERSION_17
        targetCompatibility = JavaVersion.VERSION_17
    }
    kotlinOptions {
        jvmTarget = "17"
    }
    buildFeatures {
        compose = true
    }

}

dependencies {

    implementation(libs.androidx.core.ktx)
    implementation(libs.androidx.lifecycle.runtime.ktx)
    implementation(libs.androidx.activity.compose)
    implementation(platform(libs.androidx.compose.bom))
    implementation(libs.androidx.ui)
    implementation(libs.androidx.ui.graphics)
    implementation(libs.androidx.ui.tooling.preview)
    implementation(libs.androidx.material3)
    implementation(libs.navigation.compose)
    implementation(libs.datastore.preferences)

    // 3rd party
    implementation(libs.acra.mail)
    implementation(libs.acra.dialog)
    implementation(libs.acra.notification)
    implementation(libs.acra.toast)
    implementation(libs.osmdroid.android)
    implementation(libs.okhttp)
    implementation(libs.json)
    implementation(libs.coil.compose)
    implementation(libs.coil.network.okhttp)
    implementation(libs.accompanist.permissions)
    implementation(libs.androidx.appcompat)

    testImplementation(libs.junit)
    androidTestImplementation(libs.androidx.junit)
    androidTestImplementation(libs.androidx.espresso.core)
    androidTestImplementation(platform(libs.androidx.compose.bom))
    androidTestImplementation(libs.androidx.ui.test.junit4)
    debugImplementation(libs.androidx.ui.tooling)
    debugImplementation(libs.androidx.ui.test.manifest)
}