package com.zell_mbc.publicartexplorer

import androidx.annotation.DrawableRes
import androidx.annotation.StringRes

// Constants and definitions

val ARTWORK_TYPES_KEY = "artwork_types"
val RADIUS_KEY = "radius"
val EXPERT_MODE_KEY = "expert_mode"
val LONGITUDE_KEY = "longitude"
val LATITUDE_KEY = "latitude"
val ZOOM_KEY = "zoom"
val SHOW_MUSEUM_KEY = "show_museum"
val LAUNCH_AT_CURRENT_POSITION_KEY = "launch_at_current_position"

// Preferences
object Constants {
    const val DEFAULT_ZOOM = 16.5 // 0,5km
    const val DEFAULT_EXPERT_MODE = false
    const val DEFAULT_SHOW_MUSEUM = false
    const val DEFAULT_LAUNCH_AT_CURRENT_POSITION = false

    const val SEARCH_ZOOM = 16.5 // 0,5km
    const val LOCATION_ZOOM = 19.5
    const val DEFAULT_RADIUS = 1000
}

object NodeType {
    const val TAGGED_ARTWORK = 0
    const val UNTAGGED_ARTWORK = 1

    const val UNKNOWN = 0
    const val SCULPTURE = 1
    const val STATUE = 2
    const val MUSEUM = 3
    const val GRAFFITI = 4
    const val MURAL = 5
    const val RELIEF = 6
    const val INSTALLATION = 7
    const val FOUNTAIN = 8
    const val ARCHITECTURE = 9
}

// Data class for artwork
data class Artwork(
    val id: String,
    val lat: Double,
    val lon: Double,
    val tags: MutableMap<String, String> = mutableMapOf(),
    val type: Int
)

// Data class for artwork
data class Relation(
    val id: String,
    val members: ArrayList<String> = arrayListOf<String>(),
    val tags: MutableMap<String, String> = mutableMapOf()
)

// Right now only the de server seems to work = no fallback option :-(
val apiServers = arrayOf("https://overpass-api.de/api/interpreter", "https://overpass.osm.ch/api/interpreter", "https://overpass.osm.jp/api/interpreter")

object App {
    const val url = "https://PublicArtExplorer.com"
    const val email = "publicartexplorer@zell-mbc.com"
    const val FOSS = 0
    const val PLAY = 1
}

// Navigation
sealed class Screen(val route: String, @StringRes val label: Int, @DrawableRes val icon: Int) {
    object Map : Screen("map", R.string.tab_map, R.drawable.map)
    object Settings : Screen("settings", R.string.tab_settings, R.drawable.settings)
    object Info : Screen("info", R.string.tab_info, R.drawable.info)
}

val bottomNavItems = listOf(
    Screen.Map,
    Screen.Settings,
    Screen.Info
)


