package com.zell_mbc.publicartexplorer

import android.os.Bundle
import android.preference.PreferenceManager
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.ui.Modifier
import androidx.compose.runtime.getValue
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.runtime.*
import org.osmdroid.views.MapView
import com.zell_mbc.publicartexplorer.ui.theme.PublicArtExplorerTheme
import androidx.activity.viewModels
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Surface
import com.zell_mbc.publicartexplorer.onboarding.OnboardingPage
import com.zell_mbc.publicartexplorer.data.ViewModel
import com.zell_mbc.publicartexplorer.onboarding.AppStart
import com.zell_mbc.publicartexplorer.onboarding.checkAppStart
import com.zell_mbc.publicartexplorer.screens.MainScaffold

var mapView: MapView? = null

//class MainActivity : AppCompatActivity() {
class MainActivity : ComponentActivity() {
    val viewModel by viewModels<ViewModel>()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()

        val launch = checkAppStart(this)

        // Debug
        /*val preferences = PreferenceManager.getDefaultSharedPreferences(this)
        preferences.edit().remove(LATITUDE_KEY).apply()
        preferences.edit().remove(LONGITUDE_KEY).apply()
        preferences.edit().remove(ZOOM_KEY).apply()
*/
        setContent {
            PublicArtExplorerTheme {
                var appStart by remember { mutableStateOf(launch) }
                //appStart = AppStart.FIRST_TIME_APP
                //appStart = AppStart.FIRST_TIME_VERSION
                if (appStart == AppStart.FIRST_TIME_APP) {
                    Surface(modifier = Modifier.fillMaxSize(), color = MaterialTheme.colorScheme.background) {
                        OnboardingPage(context = this, setValue = { appStart = it })
                    }
                }
                else MainScaffold(viewModel)
            }
        }
    }

    override fun onResume() {
        super.onResume()
        //this will refresh the osmdroid configuration on resuming.
        //if you make changes to the configuration, use
        //SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(this);
        //Configuration.getInstance().load(this, PreferenceManager.getDefaultSharedPreferences(this));
        mapView?.onResume() //needed for compass, my location overlays, v6.0.0 and up
    }

    override fun onPause() {
        super.onPause()
        //this will refresh the osmdroid configuration on resuming.
        //if you make changes to the configuration, use
        //SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(this);
        //Configuration.getInstance().save(this, prefs);
        mapView?.onPause()  //needed for compass, my location overlays, v6.0.0 and up
    }

    companion object {
        var firstStart = true
    }
}


