package com.zell_mbc.publicartexplorer.detailview

import android.content.Intent
import android.net.Uri
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.HorizontalDivider
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.material3.TextButton
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.text.style.TextOverflow
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import coil3.compose.AsyncImage
import com.zell_mbc.publicartexplorer.Artwork
import com.zell_mbc.publicartexplorer.ClickableEmail
import com.zell_mbc.publicartexplorer.MapillaryImage
import com.zell_mbc.publicartexplorer.PanoramaxImage
import com.zell_mbc.publicartexplorer.R
import com.zell_mbc.publicartexplorer.ShowRelationsData
import com.zell_mbc.publicartexplorer.capitalize
import com.zell_mbc.publicartexplorer.createClickableUrl
import com.zell_mbc.publicartexplorer.createWikipediaUrl
import com.zell_mbc.publicartexplorer.data.ViewModel
import com.zell_mbc.publicartexplorer.getLocalValue
import java.net.URLEncoder
import java.security.MessageDigest
import kotlin.text.contains
import kotlin.text.isNotEmpty

@Composable
fun ShowArtwork(viewModel:ViewModel, selectedArtwork: Artwork) {
    val context = LocalContext.current

    // Image section
    val imageUrl = selectedArtwork.tags["image"] ?: ""
    if (imageUrl.isNotEmpty()) ImageTag(imageUrl)

    // Panoramax
    //val panoramaxId = selectedArtwork.tags["panoramax"] ?: ""
    val panoramaxId = selectedArtwork.tags
        .entries
        .firstOrNull { it.key == "panoramax" || it.key.startsWith("panoramax:") }
        ?.value ?: ""
    if (panoramaxId.isNotEmpty()) PanoramaxImage(panoramaxId)

    val wikimediaCommons = selectedArtwork.tags["wikimedia_commons"] ?: ""
    if (wikimediaCommons.isNotEmpty()) WikimediaCommonsImage(wikimediaCommons)

    // Mapillary
    val mapillaryId = selectedArtwork.tags["mapillary"] ?: ""
    if (mapillaryId.isNotEmpty()) MapillaryImage(imageId = mapillaryId, accessToken = "MLY|9468189469959255|06c03c8accfbbe17a44f5750a146fcc4")

    // Text part

    // Artwork name and link
    var s = selectedArtwork.tags["name"] ?: ""
    if (s.isNotEmpty()) Text(context.getString(R.string.tag_name) + ": $s")

    s = createWikipediaUrl(selectedArtwork.tags["subject:wikipedia"] ?: "")
    if (s.isNotEmpty()) {
        val linkText = stringResource(R.string.artwork) + " Wikipedia"
        Text(createClickableUrl(s, linkText))
        Text("")
    }

    //s = selectedArtwork.tags["description"] ?: ""
    s = getLocalValue("description", selectedArtwork.tags, context)
    if (s.isNotEmpty()) {
        Text(context.getString(R.string.tag_description) + ": $s")
        Text("")
    }

    val nodeType = selectedArtwork.tags["tourism"] ?: ""
    if (nodeType.contains("museum")) {
        s = selectedArtwork.tags["opening_hours"] ?: ""
        if (s.isNotEmpty()) Text(s)
        s = selectedArtwork.tags["phone"] ?: ""
        if (s.isNotEmpty()) Text(s)
        s = selectedArtwork.tags["email"] ?: ""
        if (s.isNotEmpty()) ClickableEmail(s)

        s = selectedArtwork.tags["wikipedia"] ?: ""
        if (s.isNotEmpty()) {
            val tmp = createWikipediaUrl(s)
            if (tmp.isNotEmpty()) {
                Text(createClickableUrl(tmp))
            }
        }
    }
    else {
        // Artist
        s = selectedArtwork.tags["artist_name"] ?: ""
        if (s.isNotEmpty()) Text(context.getString(R.string.tag_artist) + ": $s")

        // Todo: Think this through. Should multiple languages be in the map?
        // Probably not -> pull the default and let users pick their language in Wikipedia
        // s = getLocaleValue("artist:wikipedia", selectedArtwork.tags, context)
        s = selectedArtwork.tags["artist:wikipedia"] ?: ""
        ArtistWikipedia(s)

        s = selectedArtwork.tags["artist:wikidata"] ?: ""
        ArtistWikidata(s)

        // Artwork subject
        var subject = selectedArtwork.tags["artwork_subject"] ?: ""
        s = if (subject.isNotEmpty()) {
            val resId = context.resources.getIdentifier(subject, "string", context.packageName)
            if (resId != 0) context.getString(resId) else subject
        } else ""
        if (s.isNotEmpty()) {
            s = capitalize(s) //.replaceFirstChar { if (it.isLowerCase()) it.titlecase() else it.toString() }
            Text(context.getString(R.string.tag_subject) + ": $s")
        }

        /* Artwork type
        var type = selectedArtwork.tags["artwork_type"] ?: ""
        s = if (type.isNotEmpty()) {
            val resId = context.resources.getIdentifier(type, "string", context.packageName)
            if (resId != 0) context.getString(resId) else type
        } else ""
        if (s.isNotEmpty()) {
            s = capitalize(s) //.replaceFirstChar { if (it.isLowerCase()) it.titlecase() else it.toString() }
            Text(context.getString(R.string.tag_type) + ": $s")
        }*/

        // Material
        var tag = selectedArtwork.tags["material"] ?: ""
        s = if (tag.isNotEmpty()) {
            val resId = context.resources.getIdentifier(tag, "string", context.packageName)
            if (resId != 0) context.getString(resId) else tag
        } else ""
        if (s.isNotEmpty()) {
            s = capitalize(s)
            // Can we be more specific?
            tag = selectedArtwork.tags["stone"] ?: ""
            if (tag.isNotEmpty()) s = "$s, $tag"

            Text(context.getString(R.string.tag_material) + ": $s")
        }

        s = selectedArtwork.tags["start_date"] ?: ""
        if (s.isNotEmpty()) Text(context.getString(R.string.tag_created) + ": $s")
    }

    // Website
    s = selectedArtwork.tags["website"] ?: ""
    if (s.isNotEmpty()) {
        Text(createClickableUrl(s, stringResource(R.string.website)), overflow = TextOverflow.Clip)
        Text("")
    }

    s = selectedArtwork.tags["wheelchair"] ?: ""
    if (s.isNotEmpty()) {
        val resId = context.resources.getIdentifier(s, "string", context.packageName)
        if (resId != 0) s = context.getString(resId)
        Text(context.getString(R.string.tag_wheelchair) + ": $s")
    }

    // If this node is part of a relation show the relation specific data now
    ShowRelationsData(viewModel, selectedArtwork.id)
    Text("")
    HorizontalDivider(thickness = 1.dp, color = MaterialTheme.colorScheme.primary)
    Text("")

    TextButton(modifier = Modifier.fillMaxWidth(),onClick = {
        val geoUri = "geo:${selectedArtwork.lat},${selectedArtwork.lon}"
        val intent = Intent(Intent.ACTION_VIEW, Uri.parse(geoUri))
        context.startActivity(intent)
    }) {  Text(stringResource(R.string.sendCoordinates),modifier = Modifier.fillMaxWidth(), textAlign = TextAlign.End) }

}

@Composable
fun ArtistWikipedia(s: String) {
    val linkText = stringResource(R.string.tag_artist) + " Wikipedia"
    if (s.isNotEmpty())
        when {
            s.contains("http") -> {  // A proper url
                Text(createClickableUrl(s, linkText))
                Text("")
            }
            s.contains(":") -> { // Probably Wikipedia notation 'en:Peter Randal-Page or en:Peter_Randal-Page'
                val tmp = createWikipediaUrl(s)
                if (tmp.isNotEmpty()) {
                    Text(createClickableUrl(tmp, linkText))
                    Text("")
                }
            }
        }
}

@Composable
fun ArtistWikidata(s: String) {
    val linkText = stringResource(R.string.tag_artist) + " Wikidata"
    if (s.isNotEmpty())
        when {
            s.contains("http") -> {  // A proper url
                Text(createClickableUrl(s, linkText))
                Text("")
            }
            s.contains(":") -> { // Probably Wikipedia notation 'en:Peter Randal-Page'
                val tmp = createWikipediaUrl(s)
                if (tmp.isNotEmpty()) {
                    Text(createClickableUrl(tmp, linkText))
                    Text("")
                }
            }
        }
}


@Composable
fun WikimediaCommonsImage(osmTag: String) {
    //In:  wikimedia_commons=File:Tony Stadler Skulptur Quellnymphe Ulm (1982) 02.jpg
    //Out: https://upload.wikimedia.org/wikipedia/commons/5/57/Toni_Stadler_Skulptur_Quellnymphe_Ulm_%281982%29_02.jpg

    // Extract the file name
    val filePrefix = "File:"
    val fileName = osmTag.substringAfter(filePrefix).trim()
    // Replace spaces with underscores
    val normalizedFileName = fileName.replace(' ', '_')
    // URL-encode the file name (parentheses and other special chars)
    val encodedFileName = URLEncoder.encode(normalizedFileName, "UTF-8")
        .replace("+", "_") // URLEncoder encodes spaces as '+', but Commons uses '_'
        .replace("%28", "(").replace("%29", ")") // Commons keeps parentheses unencoded in the path

    // Compute MD5 hash of the normalized file name (case-sensitive, as-is)
    val md = MessageDigest.getInstance("MD5")
    val hashBytes = md.digest(normalizedFileName.toByteArray(Charsets.UTF_8))
    val hash = hashBytes.joinToString("") { "%02x".format(it) }

    val firstChar = hash.substring(0, 1)
    val firstTwoChars = hash.substring(0, 2)

    val realImageUrl =  "https://upload.wikimedia.org/wikipedia/commons/$firstChar/$firstTwoChars/$encodedFileName"

    Box {
        AsyncImage(model = realImageUrl, contentDescription = null)
        Text(text = "© Wikipedia", color = Color.White, fontSize = 12.sp, modifier = Modifier.padding(8.dp).align(Alignment.BottomEnd), textAlign = TextAlign.End)
    }
    Text("")
}
