package com.zell_mbc.publicartexplorer.detailview

import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.HorizontalDivider
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.unit.dp
import com.zell_mbc.publicartexplorer.Artwork
import com.zell_mbc.publicartexplorer.R
import com.zell_mbc.publicartexplorer.ShowRelationsRawData
import com.zell_mbc.publicartexplorer.createClickableUrl
import com.zell_mbc.publicartexplorer.data.ViewModel
import kotlin.collections.iterator

@Composable
fun ShowRawData(viewModel: ViewModel, selectedArtwork: Artwork) {
    val tags = selectedArtwork.tags
    val context = LocalContext.current
    Box(modifier = Modifier
        .fillMaxHeight()
        .fillMaxWidth()
        .padding(8.dp)) {
        Column {
            val coordinates = "coordinates: " + selectedArtwork.lat + ", " + selectedArtwork.lon
            Text(coordinates, style = MaterialTheme.typography.bodyMedium, color = MaterialTheme.colorScheme.primary)
            for (tag in tags) {
                Text(tag.toString(), style = MaterialTheme.typography.bodyMedium, color = MaterialTheme.colorScheme.primary)
            }
            // If this node is part of a relation show the relation specific data now
            ShowRelationsRawData(viewModel, selectedArtwork.id)
            Text("")
            HorizontalDivider(thickness = 1.dp, color = MaterialTheme.colorScheme.primary)
            Text("")

            Row {
                Text(context.getString(R.string.source) + ": ")
                Text(createClickableUrl("https://www.openstreetmap.org/node/" + selectedArtwork.id, "OpenStreetMap"))
            }
        }
    }
}

