package com.zell_mbc.publicartexplorer.onboarding

import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.material3.Surface
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp


data class OnboardingModel(
    val imageRes: Int,
    val title: String,
    val description: String
)

@Composable
fun OnboardingItem(page: OnboardingModel) {
    Column(
        modifier = Modifier.fillMaxSize().padding(top = 64.dp).verticalScroll(rememberScrollState()),
        horizontalAlignment = Alignment.CenterHorizontally) {
        Surface(shape = RoundedCornerShape(16.dp)) {
            Image(painter = painterResource(id = page.imageRes), contentDescription = null,
                modifier = Modifier.height(350.dp).width(350.dp).padding(bottom = 20.dp)
            )
        }
        Text(text = page.title, style = TextStyle(fontSize = 24.sp, fontWeight = FontWeight.Bold, color = MaterialTheme.colorScheme.primary, textAlign = TextAlign.Center))
        Text(text = page.description,
            modifier = Modifier.padding(horizontal = 16.dp, vertical = 10.dp),
            style = TextStyle(fontSize = 14.sp, fontWeight = FontWeight.W400, textAlign = TextAlign.Center)
        )
    }
}
