package com.zell_mbc.publicartexplorer

import android.content.pm.PackageManager
import android.os.Build
import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.safeDrawingPadding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.LinkAnnotation
import androidx.compose.ui.text.SpanStyle
import androidx.compose.ui.text.TextLinkStyles
import androidx.compose.ui.text.buildAnnotatedString
import androidx.compose.ui.text.style.TextDecoration
import androidx.compose.ui.text.withLink
import androidx.compose.ui.unit.dp
import com.zell_mbc.publicartexplorer.data.ViewModel
import com.zell_mbc.publicartexplorer.ui.theme.link

@Composable fun InfoScreen() {
    val context = LocalContext.current

    val packageInfo = if (Build.VERSION.SDK_INT >= 33) {
        context.packageManager.getPackageInfo(
            context.packageName,
            PackageManager.PackageInfoFlags.of(0)
        )
    } else {
        @Suppress("DEPRECATION")
        context.packageManager.getPackageInfo(context.packageName, 0)
    }

    val versionCode = if (Build.VERSION.SDK_INT >= 28) {
        packageInfo.longVersionCode
    } else {
        @Suppress("DEPRECATION")
        packageInfo.versionCode.toLong()
    }

    //val flavour = context.resources.getInteger(R.integer.flavour)
    val versionName = packageInfo.versionName +
    if (BuildConfig.FLAVOUR == "foss") " FOSS" else " Play"

    val scrollState = rememberScrollState()
    Column(modifier = Modifier.safeDrawingPadding().verticalScroll(state = scrollState).padding(start = 16.dp)) {
        Surface(modifier = Modifier.size(200.dp)) {
            Image(painter = painterResource(id = R.drawable.public_art_on_the_go), contentDescription = "Logo", modifier = Modifier.align(Alignment.Start).fillMaxWidth())
        }

        val s = context.getString(R.string.version) + ": " + versionName + ", Build: " + versionCode.toString()
        Text(s, style = MaterialTheme.typography.bodyMedium, color = MaterialTheme.colorScheme.primary, modifier = Modifier.padding(start = 8.dp))
        Text(stringResource(id = R.string.author) + ": " + stringResource(id = R.string.zellMBC), modifier = Modifier.padding(start = 8.dp, top = 8.dp), style = MaterialTheme.typography.bodyMedium, color = MaterialTheme.colorScheme.primary)

        // Email
        Row(modifier = Modifier.padding(start = 8.dp)) {
            Text(stringResource(R.string.email) + ": ", style = MaterialTheme.typography.bodyMedium, color = MaterialTheme.colorScheme.primary)
            Text(buildAnnotatedString {
                append("")
                withLink(LinkAnnotation.Url(url = "mailto:" + App.email, TextLinkStyles(style = SpanStyle(color = MaterialTheme.colorScheme.link)))) { append(App.email) }
                },
                style = MaterialTheme.typography.bodyMedium,
                textDecoration = TextDecoration.Underline
            )
        }
        // AppUrl
        var url = App.url
        val currentLanguage = currentLocale(context)
        url += when (currentLanguage) {
            "de" -> "/de"
            else -> ""
        }

        Row(modifier = Modifier.padding(start = 8.dp)) {
            Text(stringResource(R.string.website) + ": ", style = MaterialTheme.typography.bodyMedium, color = MaterialTheme.colorScheme.primary)
            Text(
                buildAnnotatedString {
                    append("")
                    withLink(
                        LinkAnnotation.Url(
                            url = url,
                            TextLinkStyles(style = SpanStyle(color = MaterialTheme.colorScheme.link))
                        )
                    ) { append(url) }
                },
                style = MaterialTheme.typography.bodyMedium,
                textDecoration = TextDecoration.Underline
            )
        }
        /*
        // ThirdParty
        Text("")
        Text(stringResource(id = R.string.Copyright2), style = MaterialTheme.typography.bodyMedium, color = MaterialTheme.colorScheme.primary)
        Text(buildAnnotatedString {
            append("")
            withLink(LinkAnnotation.Url(url = stringResource(id = R.string.thirdparty), TextLinkStyles(style = SpanStyle(color = Color(LINK_COLOR))))
            ) { append(stringResource(id = R.string.thirdparty)) }
        }, style = MaterialTheme.typography.bodyMedium, textDecoration = TextDecoration.Underline)

        // Copyright
        val year = SimpleDateFormat("yyyy")
        Text(
            stringResource(id = R.string.Copyright1, year.format(Date()).toString()),
            modifier = Modifier.padding(top = 8.dp),
            style = MaterialTheme.typography.bodySmall, color = MaterialTheme.colorScheme.primary
        )
        Text(buildAnnotatedString {
            append("")
            withLink(LinkAnnotation.Url(url = stringResource(id = R.string.mediLogLicense), TextLinkStyles(style = SpanStyle(color = Color(LINK_COLOR))))
            ) { append(stringResource(id = R.string.mediLogLicense)) }
        }, style = MaterialTheme.typography.bodySmall, textDecoration = TextDecoration.Underline) */
    }
}