package com.zell_mbc.publicartexplorer.screens

import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Icon
import androidx.compose.material3.NavigationBar
import androidx.compose.material3.NavigationBarItem
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.painterResource
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.currentBackStackEntryAsState
import androidx.navigation.compose.rememberNavController
import com.zell_mbc.publicartexplorer.InfoScreen
import com.zell_mbc.publicartexplorer.Screen
import com.zell_mbc.publicartexplorer.SettingsScreen
import com.zell_mbc.publicartexplorer.bottomNavItems
import com.zell_mbc.publicartexplorer.data.ViewModel

@Composable
fun MainScaffold(viewModel: ViewModel) {
    val context = LocalContext.current

    val navController = rememberNavController()
    Scaffold(
        bottomBar = {
            NavigationBar {
                val navBackStackEntry by navController.currentBackStackEntryAsState()
                val currentRoute = navBackStackEntry?.destination?.route
                bottomNavItems.forEach { screen ->
                    NavigationBarItem(
                        icon = { Icon(painterResource(id = screen.icon), contentDescription = null) },
                        label = { Text(context.getString(screen.label)) },
                        selected = currentRoute == screen.route,
                        onClick = {
                            if (currentRoute != screen.route) {
                                navController.navigate(screen.route) {
                                    popUpTo(navController.graph.startDestinationId)
                                    launchSingleTop = true
                                }
                            }
                        }
                    )
                }
            }
        }
    ) { innerPadding ->
        NavHost(
            navController,
            startDestination = Screen.Map.route,
            Modifier.padding(innerPadding)
        ) {
            composable(Screen.Map.route) {
                MapScreen(viewModel)
                //MapContainer(modifier = Modifier, viewModel = viewModel)
            }
            composable(Screen.Settings.route) { SettingsScreen(viewModel) }
            composable(Screen.Info.route) { InfoScreen() }
        }
    }
}
