package com.zell_mbc.publicartexplorer

import android.preference.Preference
import android.preference.PreferenceManager
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.Checkbox
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.ExposedDropdownMenuBox
import androidx.compose.material3.ExposedDropdownMenuDefaults
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Switch
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Alignment.Companion.CenterVertically
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.unit.dp
import com.zell_mbc.publicartexplorer.data.ViewModel
import androidx.core.content.edit

@Composable fun SettingsScreen(viewModel: ViewModel) {
    val context = LocalContext.current

    val preferences = PreferenceManager.getDefaultSharedPreferences(context)

    val radius = preferences.getInt(RADIUS_KEY, Constants.DEFAULT_RADIUS)
    val expertModePreference = preferences.getBoolean(EXPERT_MODE_KEY, Constants.DEFAULT_EXPERT_MODE)
    val showMuseumPreference = preferences.getBoolean(SHOW_MUSEUM_KEY, Constants.DEFAULT_SHOW_MUSEUM)
    val openAppAtCurrentPositionPreference = preferences.getBoolean(LAUNCH_AT_CURRENT_POSITION_KEY, Constants.DEFAULT_LAUNCH_AT_CURRENT_POSITION)
    val lat = Double.fromBits(preferences.getLong(LATITUDE_KEY,0L))
    val lon = Double.fromBits(preferences.getLong(LONGITUDE_KEY,0L))
    val zoom = Double.fromBits(preferences.getLong(ZOOM_KEY,0L))

    var longitude by remember { mutableStateOf<Double>(lon) }
    var latitude by remember { mutableStateOf<Double>(lat) }

    //val context = LocalContext.current
 /*   val radius by viewModel.getRadius.collectAsState()
    val expertMode    by viewModel.getExpertMode.collectAsState()
    val loadCurrentPosition by viewModel.getLoadPosition.collectAsState()
    val activeArtworkTypes by viewModel.getArtworkTypes.collectAsState()
    val zoom by viewModel.getZoom.collectAsState()
    val longitude by viewModel.getLongitude.collectAsState()
    val latitude by viewModel.getLatitude.collectAsState()
*/
    val availableArtworkTypes = arrayOf("All","Sculpture", "Statue", "Mural", "Architecture", "Street Art", "Graffiti", "Installation", "Bust", "Relief","Painting", "Artistic fountains")
 //   val artworkTypeList: List<String> = activeArtworkTypes.split(",").map { it.trim() }
  //  var selectedArtworkTypes by remember { mutableStateOf(artworkTypeList) }

    var expertMode by remember { mutableStateOf<Boolean>(expertModePreference) }
    var showMuseum by remember { mutableStateOf<Boolean>(showMuseumPreference) }
    var openAppAtCurrentPosition by remember { mutableStateOf<Boolean>(openAppAtCurrentPositionPreference) }

    Column(modifier = Modifier.padding(16.dp).verticalScroll(rememberScrollState())) {
        Text("Settings", style = MaterialTheme.typography.bodyLarge, color = MaterialTheme.colorScheme.primary)
        Text("")
        SettingTextField(label = "Radius", value = radius, range = IntRange(100,10000), {
            preferences.edit {
                putInt(RADIUS_KEY, it)
            }
            //viewModel.setRadius(it)
             } )

        // Show Museum
        SwitchPreference(
            title = stringResource(R.string.showMuseum),
            summary = stringResource(R.string.showMuseumSummary),
            checked = showMuseum,
            onCheckedChange = {
                showMuseum = it
                preferences.edit { putBoolean(SHOW_MUSEUM_KEY, it).apply() }
            }
        )

        // Define if app opens at previous position or current position
        SwitchPreference(
            title = stringResource(R.string.launchAtCurrentPosition),
            summary = stringResource(R.string.launchAtCurrentPositionSummary),
            checked = openAppAtCurrentPosition,
            onCheckedChange = {
                openAppAtCurrentPosition = it
                preferences.edit { putBoolean(LAUNCH_AT_CURRENT_POSITION_KEY, it).apply() }
            }
        )

        // Expert Mode, only show for Foss or if someone supported the project on GooglePlay
        val playPurchased = false
        if (BuildConfig.FLAVOUR == "foss" || playPurchased) {
            SwitchPreference(
                title = stringResource(R.string.expertMode),
                summary = stringResource(R.string.expertModeSummary),
                checked = expertMode,
                onCheckedChange = {
                    expertMode = it
                    preferences.edit { putBoolean(EXPERT_MODE_KEY, it).apply() }
                }
            )
            Text("")
        }
/*
        var selectedTypes by remember { mutableStateOf(setOf<String>()) }

        ArtworkTypeMultiSelect(
            artworkTypes = availableArtworkTypes,
            selectedTypes = selectedTypes,
            onSelectionChange = { selectedTypes = it }
        )

        val serverNames = listOf("Germany", "Switzerland", "Japan")
        val apiServers = listOf(
            "https://overpass-api.de/api/interpreter",
            "https://overpass.osm.ch/api/interpreter",
            "https://overpass.osm.jp/api/interpreter"
        )
        var selectedServer by remember { mutableStateOf(0) }

        ServerSelector(
            serverNames = serverNames,
            serverUrls = apiServers,
            selectedIndex = selectedServer,
            onServerSelected = { selectedServer = it }
        )


                Text("Debug section:")
                Text("Coordinates: %.4f - %.4f".format(latitude, longitude))
                Text("Zoom: "+ zoom.toString())

                     ArtworkTypeCheckboxes(artworkTypes = availableArtworkTypes, selectedTypes = selectedArtworkTypes, onSelectionChange = {
                         selectedArtworkTypes = it
                         var x = selectedArtworkTypes.toString()
                         x = x.substring(1)
                         x = x.removeSuffix("]")
                         viewModel.setArtworkTypes(x)
                     })*/

        //Text("Follow me")
        Text("")
        //Text("Startup Zoom Level")
        //Text("Update location on start")
        //Text("Artwork Type:")
        /*
        Text("All", style = MaterialTheme.typography.bodyMedium, color = MaterialTheme.colorScheme.primary)
        Text("Sculpture", style = MaterialTheme.typography.bodyMedium, color = MaterialTheme.colorScheme.primary)
        Text("A work made of stone, metal, ceramic, wood, or other material.", style = MaterialTheme.typography.bodySmall, color = MaterialTheme.colorScheme.primary)
        Text("Statue", style = MaterialTheme.typography.bodyMedium, color = MaterialTheme.colorScheme.primary)
        Text("Figurative sculpture of people, animals, or gods, usually life-size or larger.", style = MaterialTheme.typography.bodySmall, color = MaterialTheme.colorScheme.primary)
        Text("Mural", style = MaterialTheme.typography.bodyMedium, color = MaterialTheme.colorScheme.primary)
        Text("Artwork painted or applied directly on a wall or large surface.", style = MaterialTheme.typography.bodySmall, color = MaterialTheme.colorScheme.primary)
        Text("Architecture", style = MaterialTheme.typography.bodyMedium, color = MaterialTheme.colorScheme.primary)
        Text("A remarkable architectural building or structure.", style = MaterialTheme.typography.bodySmall, color = MaterialTheme.colorScheme.primary)
        Text("Street_art", style = MaterialTheme.typography.bodyMedium, color = MaterialTheme.colorScheme.primary)
        Text("Modern street art, including murals, graffiti, and other forms.", style = MaterialTheme.typography.bodySmall, color = MaterialTheme.colorScheme.primary)
        Text("Graffiti", style = MaterialTheme.typography.bodyMedium, color = MaterialTheme.colorScheme.primary)
        Text("Artwork created by writing or drawing on a wall or other surface, often illicitly.", style = MaterialTheme.typography.bodySmall, color = MaterialTheme.colorScheme.primary)
        Text("Installation", style = MaterialTheme.typography.bodyMedium, color = MaterialTheme.colorScheme.primary)
        Text("Artworks that are installed in a particular place, often site-specific.", style = MaterialTheme.typography.bodySmall, color = MaterialTheme.colorScheme.primary)
        Text("bust", style = MaterialTheme.typography.bodyMedium, color = MaterialTheme.colorScheme.primary)
        Text("Sculpture representing a person's head, shoulders, and chest", style = MaterialTheme.typography.bodySmall, color = MaterialTheme.colorScheme.primary)
        Text("Relief", style = MaterialTheme.typography.bodyMedium, color = MaterialTheme.colorScheme.primary)
        Text("Sculptural artwork where figures are raised from a flat background", style = MaterialTheme.typography.bodySmall, color = MaterialTheme.colorScheme.primary)
        Text("Painting", style = MaterialTheme.typography.bodyMedium, color = MaterialTheme.colorScheme.primary)
        Text("Traditional paintings, not murals or graffiti", style = MaterialTheme.typography.bodySmall, color = MaterialTheme.colorScheme.primary)
        Text("Fountain", style = MaterialTheme.typography.bodyMedium, color = MaterialTheme.colorScheme.primary)
        Text("Artistic fountains, often with sculptural elements.", style = MaterialTheme.typography.bodySmall, color = MaterialTheme.colorScheme.primary)
  */
    }
}

@Composable
fun SettingTextField(
    label: String,
    value: Int,
    range: IntRange,
    onValueChange: (Int) -> Unit,
    modifier: Modifier = Modifier
) {
    var text by remember { mutableStateOf(value.toString()) }
    var isError by remember { mutableStateOf(false) }

    Column(modifier = modifier.padding(vertical = 8.dp)) {
        val placeholder = "0".repeat(range.last.toString().length-1)
        OutlinedTextField(
            value = text,
            placeholder = { Text(text = placeholder) },
            onValueChange = { newText ->
                // Allow only digits
                if (newText.all { it.isDigit() } || newText.isEmpty()) {
                    text = newText
                    isError = false
                    val intValue = newText.toIntOrNull()
                    isError = if ( (intValue != null) && intValue in range) false else true
                    if (intValue != null) onValueChange(intValue)
                } else {
                    // Invalid input, keep old value and show error
                    isError = true
                }
            },
            label = { Text(label) },
            isError = isError,
            keyboardOptions = KeyboardOptions(
                keyboardType = KeyboardType.Number,
                imeAction = ImeAction.Done
            ),
            singleLine = true,
            modifier = Modifier.fillMaxWidth()
        )
        if (isError) {
            Text(
                text = "Please enter a valid number (" + range.start + ":" + range.last + ")",
                color = MaterialTheme.colorScheme.error,
                style = MaterialTheme.typography.bodySmall,
                modifier = Modifier.padding(start = 16.dp, top = 4.dp)
            )
        }
    }
}

@Composable
fun ArtworkTypeCheckboxes(
    artworkTypes: Array<String>,
    selectedTypes: List<String>,
    onSelectionChange: (List<String>) -> Unit
) {
    Column() { //modifier = Modifier.padding(16.dp)) {
        Text("Select type of Artworks to be shown:")
        artworkTypes.forEach { type ->
            Row(verticalAlignment = CenterVertically, modifier = Modifier.fillMaxWidth().padding(vertical = 0.dp)) {
                Checkbox(
                    checked = selectedTypes.contains(type),
                    onCheckedChange = { isChecked ->
                        val newSelection = if (isChecked) {
                            selectedTypes + type
                        } else {
                            selectedTypes - type
                        }
                        onSelectionChange(newSelection)
                    }
                )
                Text(
                    text = type,
                    modifier = Modifier.padding(start = 8.dp)
                )
            }
        }
    }
}

@Composable
fun IntSlider(
    label: String,
    value: Int,
    valueRange: IntRange,
    onValueChange: (Int) -> Unit
) {
    Column(
        modifier = Modifier
            .fillMaxWidth()
            .padding(vertical = 8.dp)
    ) {
        Row(
            modifier = Modifier.fillMaxWidth(),
            verticalAlignment = Alignment.CenterVertically
        ) {
            Text(label)
            Spacer(modifier = Modifier.weight(1f))
            Text(value.toString())
        }
 /*       Slider(
            value = value.toFloat(),
            onValueChange = { onValueChange(it.toInt()) },
            valueRange = valueRange.first.toFloat()..valueRange.last.toFloat(),
            steps = valueRange.last - valueRange.first - 1,
            modifier = Modifier.fillMaxWidth()
        )*/
    }
}

@Composable
fun SwitchPreference(
    title: String,
    summary: String? = null,
    checked: Boolean,
    onCheckedChange: (Boolean) -> Unit
) {
    Row(
        modifier = Modifier
            .fillMaxWidth()
            .clickable { onCheckedChange(!checked) }
            .padding(16.dp),
        verticalAlignment = Alignment.CenterVertically
    ) {
        Column(modifier = Modifier.weight(1f).padding(end = 8.dp)) {
            Text(text = title)
            summary?.let { Text(text = it, style = MaterialTheme.typography.bodySmall) }
        }
        Switch(
            checked = checked,
            onCheckedChange = onCheckedChange
        )
    }
}


@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun ServerSelector(
    serverNames: List<String>,
    serverUrls: List<String>,
    selectedIndex: Int,
    onServerSelected: (Int) -> Unit
) {
    var expanded by remember { mutableStateOf(false) }

    ExposedDropdownMenuBox(
        expanded = expanded,
        onExpandedChange = { expanded = !expanded }
    ) {
        OutlinedTextField(
            value = serverNames[selectedIndex],
            onValueChange = {},
            readOnly = true,
            label = { Text("Select Overpass Server") },
            modifier = Modifier.menuAnchor().fillMaxWidth(),
            trailingIcon = { ExposedDropdownMenuDefaults.TrailingIcon(expanded = expanded) }
        )
        ExposedDropdownMenu(
            expanded = expanded,
            onDismissRequest = { expanded = false }
        ) {
            serverNames.forEachIndexed { index, name ->
                DropdownMenuItem(
                    text = { Text(name) },
                    onClick = {
                        onServerSelected(index)
                        expanded = false
                    }
                )
            }
        }
    }
}

@Composable
fun ArtworkTypeMultiSelect(
    artworkTypes: Array<String>,
    selectedTypes: Set<String>,
    onSelectionChange: (Set<String>) -> Unit
) {
    Column(Modifier.padding(16.dp)) {
        artworkTypes.forEach { type ->
            Row(
                Modifier
                    .fillMaxWidth()
                    .clickable {
                        val newSelection = selectedTypes.toMutableSet()
                        if (type in selectedTypes) newSelection.remove(type)
                        else newSelection.add(type)
                        onSelectionChange(newSelection)
                    }
                    .padding(vertical = 0.dp),
                verticalAlignment = Alignment.CenterVertically
            ) {
                Checkbox(
                    checked = type in selectedTypes,
                    onCheckedChange = {
                        val newSelection = selectedTypes.toMutableSet()
                        if (it) newSelection.add(type) else newSelection.remove(type)
                        onSelectionChange(newSelection)
                    }
                )
                Spacer(Modifier.width(8.dp))
                Text(type)
            }
        }
    }
}
